@@ -1,8 +1,11 @@
 #[cfg(test)]
 mod tests {
     extern crate wasm_bindgen_test;
+    use bitcoin_hashes::hex::ToHex;
     use bsv_wasm::hash::Hash;
+    use pbkdf2::{Params, Pbkdf2, password_hash::{Ident, PasswordHasher, Salt, SaltString}};
     use wasm_bindgen_test::*;
+    use anyhow::*;
     wasm_bindgen_test::wasm_bindgen_test_configure!();
 
 
@@ -58,4 +61,4 @@ mod tests {
 
     assert_eq!(hash.to_hex(), "d76d8ade1b94820eaf73369b79112d664456c0b2ed47189341d2306b946de5dd6dc40d473902e22b5b9eba28613aae6df58d6e66d58c8b6ba5cafe96bc0e1c29");
   }
-}
\ No newline at end of file
+}
